"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function setDefaultCollectionToAngularJson(host, defaultCollection) {
    return updateAngularJson(host, (json) => {
        if (!json.cli)
            json.cli = {};
        json.cli.defaultCollection = defaultCollection;
        return json;
    });
}
exports.setDefaultCollectionToAngularJson = setDefaultCollectionToAngularJson;
function addSchematicToAngularJson(host, projectName, collection, schematic, options) {
    return updateAngularJson(host, (json) => {
        if (!json.projects[projectName].schematics) {
            json.projects[projectName].schematics = {};
        }
        json.projects[projectName].schematics[`${collection}:${schematic}`] = options;
        return json;
    });
}
exports.addSchematicToAngularJson = addSchematicToAngularJson;
function addStyleIncludePathToAngularJson(host, projectName, path) {
    return updateAngularJson(host, (json) => {
        const options = json.projects[projectName].architect.build.options;
        if (!options.stylePreprocessorOptions) {
            options.stylePreprocessorOptions = {};
        }
        if (!options.stylePreprocessorOptions.includePaths) {
            options.stylePreprocessorOptions.includePaths = [];
        }
        const includePaths = new Set(options.stylePreprocessorOptions.includePaths);
        includePaths.add(path);
        options.stylePreprocessorOptions.includePaths = Array.from(includePaths);
        json.projects[projectName];
        return json;
    });
}
exports.addStyleIncludePathToAngularJson = addStyleIncludePathToAngularJson;
function updateAngularJson(host, callback) {
    if (host.exists('angular.json')) {
        let json = JSON.parse(host.read('angular.json').toString('utf-8'));
        json = callback(json);
        host.overwrite('angular.json', JSON.stringify(json, null, 2));
    }
    return host;
}
exports.updateAngularJson = updateAngularJson;
function saveFile(host, path, callback) {
    if (host.exists(path)) {
        const src = host.read(path).toString('utf-8');
        const dest = callback(src);
        host.overwrite(path, dest);
    }
    else {
        host.create(path, callback(''));
    }
    return host;
}
exports.saveFile = saveFile;
//# sourceMappingURL=angular-config.js.map